#include <bbgm/bbgm_feature_image_sptr.h>
#include <bbgm/bbgm_image_sptr.h>
#include <bbgm/bbgm_view_maker_sptr.h>
#include <bbgm/bbgm_viewer_sptr.h>

#include <bbgm/bbgm_apply.h>
#include <bbgm/bbgm_detect.h>
#include <bbgm/bbgm_feature_image.h>
#include <bbgm/bbgm_features.h>
#include <bbgm/bbgm_image_of.h>
#include <bbgm/bbgm_loader.h>
#include <bbgm/bbgm_measure.h>
#include <bbgm/bbgm_planes_to_sample.h>
#include <bbgm/bbgm_update.h>
#include <bbgm/bbgm_view_maker.h>
#include <bbgm/bbgm_viewer.h>

int main() { return 0; }
